==> exo.platform.packaging.source-3.5.1.zip: cs-2.2.7/eXoApplication/calendar/webapp/src/test/java/org/exoplatform/calendar/TestCalendarUtils.java <==
package org.exoplatform.calendar;


import junit.framework.TestCase;

public class TestCalendarUtils extends TestCase {
  
  public void testGetLocationDisplayString() {
    assertEquals("", CalendarUtils.getLocationDisplayString(""));
    
    assertEquals("Viet nam", CalendarUtils.getLocationDisplayString("Viet nam"));
    
    String vietnamLocation = "Vietnam(Vietnamese)";
    String countryname = "VNM";
    
    assertEquals(vietnamLocation, CalendarUtils.getLocationDisplayString(countryname));
  }
  
  public void testGenerateTimeZoneLabel() {
    assertEquals("", CalendarUtils.generateTimeZoneLabel(""));
    
    assertEquals("Viet nam", CalendarUtils.generateTimeZoneLabel("Viet nam"));
    
    String vietnamTimezone = "Asia/Ho_Chi_Minh";
    String display = "(GMT +07:00) Asia/Ho_Chi_Minh";
    
    assertEquals(display, CalendarUtils.generateTimeZoneLabel(vietnamTimezone));
  }
  
  public void testCleanValue() throws Exception {
    String values = "";
    assertEquals("", CalendarUtils.cleanValue(values));
    values = "root,";
    assertEquals("root", CalendarUtils.cleanValue(values));
    values = "root, ";
    assertEquals("root", CalendarUtils.cleanValue(values));
    values = " root     ,root ";
    assertEquals("root", CalendarUtils.cleanValue(values));
    values = " root, root , root ";
    assertEquals("root", CalendarUtils.cleanValue(values));
    values = ",root,";
    assertEquals("root", CalendarUtils.cleanValue(values));
    values = " , root , ";
    assertEquals("root", CalendarUtils.cleanValue(values));
    values = " , root , root abc ";
    assertEquals("root,root abc", CalendarUtils.cleanValue(values));
    values = "demo, root, exo/test  ,   platform/user ";
    assertEquals("demo,root,exo/test,platform/user", CalendarUtils.cleanValue(values));
  }
}

==> exo.platform.packaging.source-3.5.8.zip: cs-2.2.14/eXoApplication/calendar/webapp/src/test/java/org/exoplatform/calendar/TestCalendarUtils.java <==
package org.exoplatform.calendar;


import junit.framework.TestCase;

public class TestCalendarUtils extends TestCase {
  
  public void testGetLocationDisplayString() {
    assertEquals("", CalendarUtils.getLocationDisplayString(""));
    
    assertEquals("Viet nam", CalendarUtils.getLocationDisplayString("Viet nam"));
    
    String vietnamLocation = "Vietnam(Vietnamese)";
    String countryname = "VNM";
    
    assertEquals(vietnamLocation, CalendarUtils.getLocationDisplayString(countryname));
  }
  
  public void testGenerateTimeZoneLabel() {
    assertEquals("", CalendarUtils.generateTimeZoneLabel(""));
    
    assertEquals("Viet nam", CalendarUtils.generateTimeZoneLabel("Viet nam"));
    
    String vietnamTimezone = "Asia/Ho_Chi_Minh";
    String display = "(GMT +07:00) Asia/Ho_Chi_Minh";
    
    assertEquals(display, CalendarUtils.generateTimeZoneLabel(vietnamTimezone));
  }
  
  public void testCleanValue() throws Exception {
    String values = "";
    assertEquals("", CalendarUtils.cleanValue(values));
    values = "root,";
    assertEquals("root", CalendarUtils.cleanValue(values));
    values = "root, ";
    assertEquals("root", CalendarUtils.cleanValue(values));
    values = " root     ,root ";
    assertEquals("root", CalendarUtils.cleanValue(values));
    values = " root, root , root ";
    assertEquals("root", CalendarUtils.cleanValue(values));
    values = ",root,";
    assertEquals("root", CalendarUtils.cleanValue(values));
    values = " , root , ";
    assertEquals("root", CalendarUtils.cleanValue(values));
    values = " , root , root abc ";
    assertEquals("root,root abc", CalendarUtils.cleanValue(values));
    values = "demo, root, exo/test  ,   platform/user ";
    assertEquals("demo,root,exo/test,platform/user", CalendarUtils.cleanValue(values));
  }
  
  /**
   * Tests CalendarUtils.isValidEmailAddress
   */
  public void testValidEmail() {
    assertTrue(CalendarUtils.isValidEmailAddresses("test@com"));
    assertFalse(CalendarUtils.isValidEmailAddresses("test"));
    assertFalse(CalendarUtils.isValidEmailAddresses("test;]["));
    assertTrue(CalendarUtils.isValidEmailAddresses("quocviet.pfiev@gmail.com"));
  }
}
